drive_with_fragments

Function drive_with_fragments 

pub async fn drive_with_fragments<S, C, E, F>(
    app: WireframeApp<S, C, E, F>,
    codec: &F,
    fragmenter: &Fragmenter,
    payload: Vec<u8>,
) -> Result<Vec<Vec<u8>>, Error>
where S: TestSerializer, C: Send + 'static, E: Packet, F: FrameCodec,
Fragment payload, encode each fragment into a codec frame, and drive through app.

Errors

Returns any I/O, fragmentation, or codec error encountered during encoding, transport, or decoding.