drive_with_partial_frames_mut

Function drive_with_partial_frames_mut 

pub async fn drive_with_partial_frames_mut<S, C, E, F>(
    app: &mut WireframeApp<S, C, E, F>,
    codec: &F,
    payloads: Vec<Vec<u8>>,
    chunk_size: NonZero<usize>,
) -> Result<Vec<Vec<u8>>, Error>
where S: TestSerializer, C: Send + 'static, E: Packet, F: FrameCodec,
Drive a mutable app with payloads in chunks of chunk_size.

Errors

Returns any I/O or codec error encountered during encoding, transport, or decoding.