macro_rules! push_expect {
($fut:expr) => { ... };
($fut:expr, $msg:expr) => { ... };
}Expand description
Await a push future and return a contextualized error on failure.
macro_rules! push_expect {
($fut:expr) => { ... };
($fut:expr, $msg:expr) => { ... };
}Await a push future and return a contextualized error on failure.