obs_handle

Function obs_handle 

pub fn obs_handle() -> ObservabilityHandle
rstest fixture returning an ObservabilityHandle for test assertions.

Named obs_handle (rather than observability) to avoid a name collision with the observability module at the crate root, following the logginglogger naming convention used by [crate::logger].

Examples

use wireframe_testing::obs_handle;

let mut obs = obs_handle();
obs.clear();