pub async fn drive_with_fragments<S, C, E, F>(
app: WireframeApp<S, C, E, F>,
codec: &F,
fragmenter: &Fragmenter,
payload: Vec<u8>,
) -> Result<Vec<Vec<u8>>, Error>Expand description
Fragment payload, encode each fragment into a codec frame, and drive
through app.
Errors
Returns any I/O, fragmentation, or codec error encountered during encoding, transport, or decoding.